==> qtjambi-xml-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiXml/QDomEntity_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomEntity(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomEntity")
    QDomEntity *_ptr = reinterpret_cast<QDomEntity *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomEntity()
void __qt_construct_QDomEntity(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomEntity()")
    Q_UNUSED(__java_arguments)
    QDomEntity *__qt_this = new(__qtjambi_ptr) QDomEntity();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDomEntity::QDomEntity()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntity_initialize_1native__Lio_qt_xml_QDomEntity_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomEntity::QDomEntity()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomEntity, sizeof(QDomEntity), typeid(QDomEntity), 0, false, &deleter_QDomEntity, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomEntity(QDomEntity)
void __qt_construct_QDomEntity_cref_QDomEntity(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomEntity(QDomEntity)")
    jobject x0 = __java_arguments[0].l;
    const QDomEntity& __qt_x0 = qtjambi_cast<const QDomEntity&>(__jni_env, x0);
    QDomEntity *__qt_this = new(__qtjambi_ptr) QDomEntity(__qt_x0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDomEntity::QDomEntity(QDomEntity)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntity_initialize_1native__Lio_qt_xml_QDomEntity_2Lio_qt_xml_QDomEntity_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomEntity::QDomEntity(QDomEntity)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomEntity_cref_QDomEntity, sizeof(QDomEntity), typeid(QDomEntity), 0, false, &deleter_QDomEntity, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomEntity
void __qt_destruct_QDomEntity(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomEntity")
    reinterpret_cast<QDomEntity*>(ptr)->~QDomEntity();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomEntity::notationName()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntity_notationName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomEntity *__qt_this = QtJambiAPI::objectFromNativeId<QDomEntity>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomEntity::notationName()const", __this_nativeId)
        QString __qt_return_value = __qt_this->notationName();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomEntity::operator=(QDomEntity)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntity_assign_1native_1cref_1QDomEntity__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomEntity *__qt_this = QtJambiAPI::objectFromNativeId<QDomEntity>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomEntity::operator=(QDomEntity)", __this_nativeId)
        const QDomEntity& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomEntity>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomEntity::publicId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntity_publicId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomEntity *__qt_this = QtJambiAPI::objectFromNativeId<QDomEntity>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomEntity::publicId()const", __this_nativeId)
        QString __qt_return_value = __qt_this->publicId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomEntity::systemId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntity_systemId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomEntity *__qt_this = QtJambiAPI::objectFromNativeId<QDomEntity>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomEntity::systemId()const", __this_nativeId)
        QString __qt_return_value = __qt_this->systemId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntity_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomEntity *__qt_this = QtJambiAPI::objectFromNativeId<QDomEntity>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomEntity(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomEntity>("QDomEntity", "io/qt/xml/QDomEntity");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDomEntity, {
        ConstructorInfo(&__qt_construct_QDomEntity, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomEntity_cref_QDomEntity, "Lio/qt/xml/QDomEntity;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomEntity);
    registerMetaType<QDomEntity>("QDomEntity");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-xml-debuginfo-linux-x64-6.6.1.jar: sources/QtJambiXml/QDomEntity_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomEntity(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomEntity")
    QDomEntity *_ptr = reinterpret_cast<QDomEntity *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomEntity()
void __qt_construct_QDomEntity_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomEntity()")
    Q_UNUSED(__java_arguments)
    QDomEntity *__qt_this = new(__qtjambi_ptr) QDomEntity();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QDomEntity(QDomEntity)
void __qt_construct_QDomEntity_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomEntity(QDomEntity)")
    jobject x0 = __java_arguments[0].l;
    const QDomEntity& __qt_x0 = qtjambi_cast<const QDomEntity& >(__jni_env, x0);
    QDomEntity *__qt_this = new(__qtjambi_ptr) QDomEntity(__qt_x0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QDomEntity
void __qt_destruct_QDomEntity(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomEntity")
    reinterpret_cast<QDomEntity*>(ptr)->~QDomEntity();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomEntity::QDomEntity()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntity_initialize_1native__Lio_qt_xml_QDomEntity_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomEntity::QDomEntity()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomEntity_0, sizeof(QDomEntity), typeid(QDomEntity), false, &deleter_QDomEntity, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomEntity::QDomEntity(QDomEntity)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntity_initialize_1native__Lio_qt_xml_QDomEntity_2Lio_qt_xml_QDomEntity_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomEntity::QDomEntity(QDomEntity)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomEntity_1, sizeof(QDomEntity), typeid(QDomEntity), false, &deleter_QDomEntity, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomEntity::notationName()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntity_notationName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomEntity *__qt_this = QtJambiAPI::objectFromNativeId<QDomEntity>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomEntity::notationName()const", __qt_this)
        QString __qt_return_value = __qt_this->notationName();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomEntity::operator=(QDomEntity)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntity_assign_1native_1cref_1QDomEntity__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomEntity *__qt_this = QtJambiAPI::objectFromNativeId<QDomEntity>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomEntity::operator=(QDomEntity)", __qt_this)
        const QDomEntity& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomEntity>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomEntity::publicId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntity_publicId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomEntity *__qt_this = QtJambiAPI::objectFromNativeId<QDomEntity>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomEntity::publicId()const", __qt_this)
        QString __qt_return_value = __qt_this->publicId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomEntity::systemId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntity_systemId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomEntity *__qt_this = QtJambiAPI::objectFromNativeId<QDomEntity>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomEntity::systemId()const", __qt_this)
        QString __qt_return_value = __qt_this->systemId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntity_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomEntity *__qt_this = QtJambiAPI::objectFromNativeId<QDomEntity>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomEntity(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomEntity>("QDomEntity", "io/qt/xml/QDomEntity");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDomEntity, {
        ConstructorInfo(&__qt_construct_QDomEntity_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomEntity_1, "Lio/qt/xml/QDomEntity;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomEntity);
    registerMetaType<QDomEntity>("QDomEntity");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
